pub enum OpenTxStatus {
Pending,
Merged(H256),
Committed(H256),
Rejected(String),
}Variants
Pending
Status “pending”. The open transaction is in the pool, and not proposed yet.
Merged(H256)
Status “merged”. The open transaction is generated by merging multiple open transactions and is still unsigned.
Committed(H256)
Status “committed”. The open transaction has been committed to the canonical chain.
Rejected(String)
Due to storage limitations, the pool can only hold the most recently removed transactions.